@@ -15,17 +15,7 @@
 //! # }
 //! ```
 
-#[cfg(feature = "std")]
-use std::{
-    convert::Infallible,
-    ops::{Index, IndexMut},
-};
-
-#[cfg(not(feature = "std"))]
-use core::{
-    convert::Infallible,
-    ops::{Index, IndexMut},
-};
+use crate::std_lib::{Index, IndexMut, Infallible};
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -36,23 +26,21 @@ use snafu::Snafu;
 ///
 /// If you pass an invalid position to a method, the game will panic. Remember to check the target position validity when dealing with user input.
 #[derive(Clone, Debug)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct ConnectFour {
-    pub board: [Column; 7],
-    pub next: Player,
-    pub state: GameState,
+    board: [Column; 7],
+    next: Player,
+    state: GameState,
 }
 
 /// The column of the game board.
 ///
 /// This is a stack-vector-like struct. You can access its inner elements by using index directly.
 #[derive(Clone, Debug, Eq, PartialEq)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
-pub struct Column {
-    pub column: [Option<Player>; 6],
-    pub occupied: usize,
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+struct Column {
+    column: [Option<Player>; 6],
+    occupied: usize,
 }
 
 impl Column {
@@ -91,8 +79,7 @@ impl IndexMut<usize> for Column {
 
 /// The game players.
 #[derive(Clone, Copy, Debug, Eq, PartialEq)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub enum Player {
     Player0,
     Player1,
@@ -110,8 +97,7 @@ impl Player {
 
 /// The game state.
 #[derive(Clone, Debug, Eq, PartialEq)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub enum GameState {
     Win(Player),
     Tie,
@@ -131,13 +117,7 @@ impl ConnectFour {
     /// Get a cell reference from the game board.
     /// Panic if the target position is out of bounds.
     pub fn get(&self, row: usize, col: usize) -> &Option<Player> {
-        &self.board[row][col]
-    }
-
-    /// Get a mutable cell reference from the game board.
-    /// Panic if the target position is out of bounds.
-    pub fn get_mut(&mut self, row: usize, col: usize) -> &mut Option<Player> {
-        &mut self.board[row][col]
+        &self.board[5 - row][col]
     }
 
     /// Check if the game is ended.
@@ -205,7 +185,7 @@ impl ConnectFour {
             }
         }
 
-        if (0..7).all(|col| !self.board[col][5].is_some()) {
+        if (0..7).all(|col| self.board[col][5].is_some()) {
             self.state = GameState::Tie;
         }
     }
