@@ -18,11 +18,7 @@
 //! # }
 //! ```
 
-#[cfg(feature = "std")]
-use std::collections::VecDeque;
-
-#[cfg(not(feature = "std"))]
-use alloc::{collections::VecDeque, vec::Vec};
+use crate::std_lib::{Vec, VecDeque};
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -39,19 +35,17 @@ use snafu::Snafu;
 ///
 /// If you pass an invalid position to a method, the game will panic. Remember to check the target position validity when dealing with user input.
 #[derive(Clone, Debug)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct Minesweeper {
-    pub board: Vec<Cell>,
-    pub height: usize,
-    pub width: usize,
-    pub state: GameState,
+    board: Vec<Cell>,
+    height: usize,
+    width: usize,
+    state: GameState,
 }
 
 /// The cell of the Minesweeper board.
 #[derive(Clone, Copy, Debug, Eq, PartialEq)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct Cell {
     pub is_mine: bool,
     pub mine_adjacent: usize,
@@ -72,8 +66,7 @@ impl Cell {
 
 /// The Minesweeper game state.
 #[derive(Clone, Debug, Eq, PartialEq)]
-#[cfg(feature = "serde")]
-#[derive(Deserialize, Serialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub enum GameState {
     Win,
     Exploded(Vec<(usize, usize)>),
@@ -164,16 +157,6 @@ impl Minesweeper {
         &self.board[row * self.width + col]
     }
 
-    /// Get a mutable cell reference from the game board.
-    /// Panic if the target position is out of bounds.
-    pub fn get_mut(&mut self, row: usize, col: usize) -> &mut Cell {
-        if row >= self.height || col >= self.width {
-            panic!("Invalid position: ({}, {})", row, col);
-        }
-
-        &mut self.board[row * self.width + col]
-    }
-
     /// Click a cell on the game board.
     ///
     /// Clicking an already revealed cell will unreveal its adjacent cells if the flagged cell count around it equals to its adjacent mine count.
